<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX Manager Utilizator</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Administraţie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Adaugă utilizator nou</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Adaugă cont utilizator</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Reenter password for new user</source>
        <translation>Introduceți o parolă pentru noul cont</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>confirm password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <location filename="../mainwindow.ui" line="1118"/>
        <source>Username of new user</source>
        <translation>Nume cont nou</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>User login name:</source>
        <translation>Nume utilizator:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <location filename="../mainwindow.ui" line="416"/>
        <location filename="../mainwindow.ui" line="1134"/>
        <source>Enter username of new user</source>
        <translation>Introduceți un nou nume de cont</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="422"/>
        <source>username</source>
        <translation>numeutilizator</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Password for new user</source>
        <translation>Parolă pentru cont nou:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>User password:</source>
        <translation>Parolă utilizator:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Enter password for new user</source>
        <translation>Introduceți o parolă pentru noul cont</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>Confirm user password:</source>
        <translation>Confirmați parolă utilizator:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>Delete User Account</source>
        <translation>Șterge cont utilizator</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>Select user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <location filename="../mainwindow.ui" line="1209"/>
        <location filename="../mainwindow.ui" line="1222"/>
        <location filename="../mainwindow.ui" line="1346"/>
        <location filename="../mainwindow.ui" line="1368"/>
        <source>Select user to delete</source>
        <translation>Alegere cont de șters</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>User to delete:</source>
        <translation>Cont de șters:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Șterge și directorul home al utilizatorului</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Delete user home directory</source>
        <translation>Șterge directorul home al utilizatorului</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="359"/>
        <source>Rename User Account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="371"/>
        <location filename="../mainwindow.ui" line="483"/>
        <source>Select user to modify:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>New user name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Change User Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>new password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>Confirm new password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>confirm new password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="496"/>
        <source>New user password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="527"/>
        <source>Options</source>
        <translation>Opțiuni</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Repair a user configuration</source>
        <translation>Reparare configurare utilizator</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="564"/>
        <location filename="../mainwindow.ui" line="1271"/>
        <source>Modify User Account</source>
        <translation>Modifică cont utilizator</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Select user to repair</source>
        <translation>Selectați cont utilizator de reparat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="579"/>
        <location filename="../mainwindow.ui" line="1355"/>
        <source>User to change:</source>
        <translation>Cont de modificat:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="624"/>
        <source>Restore Defaults</source>
        <translation>Restaurare setarile originale</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Restabilire configurație a browserului la setarile implicite ale MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="651"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Setări Mozilla (Firefox sau Iceweasel)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="654"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>Restabilire apartenența de grup la setarile implicite ale MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="667"/>
        <source>Group memberships</source>
        <translation>Apartenență de grup</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>Change Autologin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="686"/>
        <source>Log in automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="693"/>
        <source>Require password to log in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="708"/>
        <source>Copy/Sync</source>
        <translation>Copiere/Sincronizare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="735"/>
        <source>Copy Between Desktops</source>
        <translation>Copiere intre desktop-uri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="762"/>
        <location filename="../mainwindow.ui" line="829"/>
        <source>Select desktop to copy from</source>
        <translation>Selectați de pe ce desktop să se copieze</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="775"/>
        <source>Select to only copy files</source>
        <translation>Selectați să se copieze numai fișiere</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Copy only</source>
        <translation>Numai copiere</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="794"/>
        <location filename="../mainwindow.ui" line="807"/>
        <source>Select desktop to copy to</source>
        <translation>Selectați desktopul destinație</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="816"/>
        <source>Copy to:</source>
        <translation>Copiere către:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="838"/>
        <source>Copy from:</source>
        <translation>Copiere de la:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="851"/>
        <source>Select to copy and then delete differences</source>
        <translation>Selectați să se copieze și apoi să se șteargă diferențele</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="854"/>
        <source>Sync</source>
        <translation>Sincronizare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select to copy/sync Shared</source>
        <translation>Alegeți să se copieze/sincronizeze Shared </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="903"/>
        <source>Shared folder</source>
        <translation>Director comun</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="916"/>
        <source>Select to copy/sync entire home</source>
        <translation>Selectați să se copieze/sincronizeze intregul director home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Entire home</source>
        <translation>Intreaga partiție home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="935"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Selectați să se copieze/sincronizeze browser-ul implicit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="938"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Setări Mozilla (Firefox sau Iceweasel)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="951"/>
        <source>Select to copy/sync Documents</source>
        <translation>Alegeți să se copieze/sincronizeze Documents </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Documents folder</source>
        <translation>Dosar documente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="961"/>
        <source>What to copy/sync:</source>
        <translation>Ce să se copieze/sincronizeze:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="977"/>
        <source>Progress</source>
        <translation>Progres</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1007"/>
        <location filename="../mainwindow.ui" line="1023"/>
        <source>Status of the changes</source>
        <translation>Situație a schimbărilor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1026"/>
        <source>Status:</source>
        <translation>Situație:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1042"/>
        <source>Progress of the changes</source>
        <translation>Progres al schimbărilor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1079"/>
        <source>Add/Remove Groups</source>
        <translation>Adaugare/Ștergere grup</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1091"/>
        <source>Add Group</source>
        <translation>Adaugare grup</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1121"/>
        <source>Group name:</source>
        <translation>Nume grup:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1140"/>
        <source>groupname</source>
        <translation>numegrup</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1169"/>
        <source>Delete Group</source>
        <translation>Ștergere grup</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1231"/>
        <source>Group to delete:</source>
        <translation>Grup de șters:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>Group Membership</source>
        <translation>Apartenență de grup</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1375"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Grupurile la care utilizatorul aparține (schimbați grupurile selectând casetele corespunzătoare):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1395"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system.  Use Repair tab to restore the original memberships if you made a mistake.</source>
        <translation>*Vă rugăm să verificați selecțiile înainte de a aplica, atribuirea uniu grup greșit poate strica sistemul. Dacă ați făcut o greșeală, utilizați funcția de reparare pentru a restaura apartenența originală. </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Apply any changes</source>
        <translation>Aplică toate schimbările</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>Apply</source>
        <translation>Aplică</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1465"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1472"/>
        <source>Cancel any changes then quit</source>
        <translation>Anulează toate schimbările și închide programul</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1475"/>
        <source>Close</source>
        <translation>Închidere</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1523"/>
        <source>Display help </source>
        <translation>Afișează ajutor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1526"/>
        <source>Help</source>
        <translation>Ajutor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1533"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1540"/>
        <source>About this application</source>
        <translation>Informații despre program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1543"/>
        <source>About...</source>
        <translation>Despre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1550"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <location filename="../mainwindow.cpp" line="141"/>
        <location filename="../mainwindow.cpp" line="149"/>
        <location filename="../mainwindow.cpp" line="162"/>
        <location filename="../mainwindow.cpp" line="173"/>
        <location filename="../mainwindow.cpp" line="182"/>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="617"/>
        <location filename="../mainwindow.cpp" line="634"/>
        <location filename="../mainwindow.cpp" line="665"/>
        <location filename="../mainwindow.cpp" line="674"/>
        <location filename="../mainwindow.cpp" line="819"/>
        <location filename="../mainwindow.cpp" line="932"/>
        <source>none</source>
        <translation>niciunul</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>Configurația utilizatorului va fi reparată. Închideți acum toate celalalte aplicații. La terminare, logout si reporniți computerul. Sigur doriți să reparați contul acum?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="225"/>
        <source>User group membership was restored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>Mozilla settings were reset.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="237"/>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>Autologin options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="238"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="249"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Înainte de copiere, închideți toate celelalte aplicații. Asigurați-vă că spațiul pe destinație este suficient de mare pentru fișierele pe care le copiați. Copierea între desktopuri poate suprascrie sau șterge fișiere sau preferințele pe desktopul destinație. Sigur doriți să continuați?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Synchronizing desktop...</source>
        <translation>Sincronizare desktop...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>Copying desktop...</source>
        <translation>Configurare desktop... </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Numele utilizatorului trebuie să aibă
cel puțin 2 caractere. Alegeți alt nume
înainte de a continua.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <location filename="../mainwindow.cpp" line="366"/>
        <source>Password entries do not match. Please try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="353"/>
        <source>The user was added ok.</source>
        <translation>Contul a fost adăugat cu succes.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="357"/>
        <source>Failed to add the user.</source>
        <translation>Nu s-a reușit adăugarea cont utilizator.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>Password successfully changed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>Failed to change password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="408"/>
        <source>The user has been deleted.</source>
        <translation>Cont utilizator a fost șters.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>Failed to delete the user.</source>
        <translation>Nu s-a putut șterge cont utilizator.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Numele grupului de lucru trebuie să aibă cel puțin 2 caractere. Alegeți alt nume înainte de a continua.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="429"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <source>The system group was added ok.</source>
        <translation>Grupul de sistem a fost adăugat cu succes.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Failed to add the system group.</source>
        <translation>Nu s-a putut adăuga grupul de sistem.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="451"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>The group has been deleted.</source>
        <translation>Grupul a fost șters.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>Failed to delete the group.</source>
        <translation>Nu s-a putut șterge grupul.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="483"/>
        <source>The changes have been applied.</source>
        <translation>Schimbările au fost implementate.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="486"/>
        <source>Failed to apply group changes</source>
        <translation>Nu s-au putut implemeta schimbările de grup.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="499"/>
        <source>The selected user name is currently in use.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="543"/>
        <source>The user was renamed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="556"/>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Sincronizare desktop...OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="558"/>
        <location filename="../mainwindow.cpp" line="587"/>
        <source>Copying desktop...ok</source>
        <translation>Copiere desktop...OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Sincronizare desktop...nereușită</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="593"/>
        <source>Copying desktop...failed</source>
        <translation>Copiere desktop...nereușită</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="611"/>
        <location filename="../mainwindow.cpp" line="871"/>
        <location filename="../mainwindow.cpp" line="879"/>
        <source>browse...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="782"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="783"/>
        <source>Version: </source>
        <translation>Versiune:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="784"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Simplu configurator de conturi utilizator pentru MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="786"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="787"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="802"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="872"/>
        <source>Select folder to copy to</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>Licență</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Anulează</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Închide</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="41"/>
        <source>You must run this program as root.</source>
        <translation>Trebuie să rulați programul ca administrator.</translation>
    </message>
</context>
</TS>
